@@ -46,7 +46,7 @@ def init(version=None, mem="4096", packages=[]):
     ApplicationSetup = autoclass('org.terrier.utility.ApplicationSetup')
     from utils import Utils
     from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
-    from index import FilesIndexer, TRECCollectionIndexer, DFIndexer
+    from index import Indexer, FilesIndexer, TRECCollectionIndexer, DFIndexer
 
     # Make imports global
     globals()["Utils"]=Utils
